"""Module defining the attachment model for attachments."""

import uuid
from enum import Enum
from typing import Optional

from pydantic import BaseModel, Field


class AttachmentMode(str, Enum):
    """Mode of attachment open."""

    READ = "read"
    WRITE = "write"


class Attachment(BaseModel):
    """Model representing an attachment. Id 'None' is used for uploads."""

    id: Optional[uuid.UUID] = Field(None, alias="ID")
    full_name: str = Field(..., alias="FullName")
    mime_type: str = Field(..., alias="MimeType")



"""UiPath Guardrails Models.

This module contains models related to UiPath Guardrails service.
"""

from ._guardrails_service import GuardrailsService
from .guardrails import (
    AllFieldsSelector,
    ApplyTo,
    BaseGuardrail,
    BooleanOperator,
    BooleanRule,
    BuiltInValidatorGuardrail,
    CustomGuardrail,
    EnumListParameterValue,
    FieldReference,
    FieldSelector,
    FieldSource,
    Guardrail,
    GuardrailScope,
    GuardrailSelector,
    GuardrailType,
    MapEnumParameterValue,
    NumberOperator,
    NumberParameterValue,
    NumberRule,
    Rule,
    SelectorType,
    SpecificFieldsSelector,
    UniversalRule,
    ValidatorParameter,
    WordOperator,
    WordRule,
)

__all__ = [
    "GuardrailsService",
    "FieldSource",
    "ApplyTo",
    "FieldReference",
    "SelectorType",
    "AllFieldsSelector",
    "SpecificFieldsSelector",
    "FieldSelector",
    "BaseGuardrail",
    "GuardrailType",
    "Guardrail",
    "BuiltInValidatorGuardrail",
    "CustomGuardrail",
    "WordOperator",
    "WordRule",
    "NumberOperator",
    "NumberRule",
    "BooleanOperator",
    "BooleanRule",
    "UniversalRule",
    "Rule",
    "ValidatorParameter",
    "EnumListParameterValue",
    "MapEnumParameterValue",
    "NumberParameterValue",
    "GuardrailScope",
    "GuardrailSelector",
]
